@@ -9,6 +9,7 @@ from pathlib import Path
 
 import selenium
 from selenium import webdriver
+from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.firefox.options import Options as FirefoxOptions
 from selenium.webdriver.chrome.options import Options as ChromeOptions
@@ -48,6 +49,7 @@ class NoImagesInWebElementError(Exception):
 
 
 def pick_best_actual_image(actual_images: List[WebElement]) -> WebElement:
+    log = get_logger("pick_best_actual_image")
     if len(actual_images) == 0:
         raise NoImagesInWebElementError()
     elif len(actual_images) == 1:
@@ -59,10 +61,11 @@ def pick_best_actual_image(actual_images: List[WebElement]) -> WebElement:
                 scores[i] += 1
                 if "encrypted-tbn0.gstatic.com" in actual_image.get_attribute("src"):
                     scores[i] -= 1
-            except selenium.common.exceptions.StaleElementReferenceException as exc:
+            except StaleElementReferenceException as exc:
                 # this error is often accompanied by: Message: stale element reference: element is not attached to the page document
                 # could be some race condition, or maybe the page is changing between the actual_images getting populated and this method getting called
                 # either way - we will continue here and raise an error later if there are no images to choose from
+                log.warning(f"skipping image due to stale reference: {exc}")
                 continue
         if len(scores) == 0:
             raise NoImagesInWebElementError()
@@ -166,13 +169,16 @@ def fetch_google_image_urls(
                         ) from exc
                     continue
             image_link = dict()
-            if actual_image.get_attribute(
-                "src"
-            ) and "http" in actual_image.get_attribute("src"):
-                image_link.update({"src": actual_image.get_attribute("src")})
-                image_link.update({"alt": actual_image.get_attribute("alt")})
-
-            else:
+            try:
+                if actual_image.get_attribute(
+                    "src"
+                ) and "http" in actual_image.get_attribute("src"):
+                    image_link.update({"src": actual_image.get_attribute("src")})
+                    image_link.update({"alt": actual_image.get_attribute("alt")})
+                else:
+                    continue
+            except StaleElementReferenceException as exc:
+                log.warning(f"skipping image due to stale reference: {exc}")
                 continue
 
             if track_related:
